@@ -1,14 +1,13 @@
 # -*- coding: utf-8 -*-
-import pytest
+from __future__ import print_function
 from solution import utils
 
 
 def test_html_attrs():
     expected = u'class="myclass" data-id="1" id="text1" checked'
-    attrs = {'id':'text1', 'classes':'myclass', 'data_id':1, 'checked':True}
+    attrs = {'id': 'text1', 'classes': 'myclass', 'data_id': 1, 'checked': True}
     result = utils.get_html_attrs(attrs)
-    print result
+    print(result)
     assert result == expected
     assert utils.get_html_attrs() == u''
 
-    
\ No newline at end of file
